@@ -200,16 +200,9 @@ uint64_t SquareBinaryMatrix::times_sse(uint64_t v) const {
   return res;
 }
 
-uint64_t SquareBinaryMatrix::times(uint64_t v) const {
-  return times_sse(v);
-}
-
 #else
 
 uint64_t SquareBinaryMatrix::times_sse(uint64_t v) const { return 0; }
-uint64_t SquareBinaryMatrix::times(uint64_t v) const {
-  return times_unrolled(v);
-}
 
 #endif
 
